/* Prepare for a Q4 */
/* this template uses parameters $INPUT_MONTHS and $NUMBER_OF_MONTHS in addition
 * to the general parameters
 */

/* first, execute this: */

delete from tmprolling
;

/* then, for each month being queried for, 
 * determine the span of months that forms the input to the rolling average
 * for example, 199503 has the months 199501, 199502, 199503 as it input, while
 * every month 199506 and after has itself and the prior 5 months as inputs.
 * Along with the months, the number of months is required.
 * Execute the following once for each target month, plugging in the appropriate
 * input month range and number of months as required in addition to the usual
 * template parameters.
 * put the range of months in $INPUT_MONTHS
 * put the number of input months in $NUMBER_OF_MONTHS
 *
 * i.e.:
 * For $CURRENT_TIME in children of $TIMEMEMBER
 *   Execute following template
 */

insert into tmprolling (
	product_level, 
	customer_level,
	channel_level,
	time_level,
	dollarsales
)
select
	a.product_level, 
	a.customer_level,
	a.channel_level,
	$CURRENT_TIME,
	sum (a.dollarsales) / $NUMBER_OF_MONTHS As dollarsales
from
	actvars a, prodlevel, custlevel
where
	    a.time_level in ($INPUT_MONTHS)
	and prodlevel.code_level = a.product_level
	and custlevel.store_level = a.customer_level
	and prodlevel.$PROD_GIVEN_LEVEL_FNAME = '$PRODMEMBER'
	and custlevel.$CUST_GIVEN_LEVEL_FNAME = '$CUSTMEMBER'
group by
	a.product_level, 
	a.customer_level,
	a.channel_level
;

/* end of template */
